# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: show.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import department_pb2 as department__pb2
from . import filter_pb2 as filter__pb2
from . import host_pb2 as host__pb2
from . import job_pb2 as job__pb2
from . import service_pb2 as service__pb2
from . import subscription_pb2 as subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nshow.proto\x12\x04show\x1a\x10\x64\x65partment.proto\x1a\x0c\x66ilter.proto\x1a\nhost.proto\x1a\tjob.proto\x1a\rservice.proto\x1a\x12subscription.proto\"\x89\x02\n\x04Show\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_min_cores\x18\x03 \x01(\x02\x12\x19\n\x11\x64\x65\x66\x61ult_max_cores\x18\x04 \x01(\x02\x12\x15\n\rcomment_email\x18\x05 \x01(\t\x12\x17\n\x0f\x62ooking_enabled\x18\x06 \x01(\x08\x12\x18\n\x10\x64ispatch_enabled\x18\x07 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x08 \x01(\x08\x12#\n\nshow_stats\x18\t \x01(\x0b\x32\x0f.show.ShowStats\x12\x18\n\x10\x64\x65\x66\x61ult_min_gpus\x18\n \x01(\x02\x12\x18\n\x10\x64\x65\x66\x61ult_max_gpus\x18\x0b \x01(\x02\"$\n\x07ShowSeq\x12\x19\n\x05shows\x18\x01 \x03(\x0b\x32\n.show.Show\"\x87\x02\n\tShowStats\x12\x16\n\x0erunning_frames\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65\x61\x64_frames\x18\x02 \x01(\x05\x12\x16\n\x0epending_frames\x18\x03 \x01(\x05\x12\x14\n\x0cpending_jobs\x18\x04 \x01(\x05\x12\x19\n\x11\x63reated_job_count\x18\x05 \x01(\x03\x12\x1b\n\x13\x63reated_frame_count\x18\x06 \x01(\x03\x12\x1c\n\x14rendered_frame_count\x18\x07 \x01(\x03\x12\x1a\n\x12\x66\x61iled_frame_count\x18\x08 \x01(\x03\x12\x16\n\x0ereserved_cores\x18\t \x01(\x02\x12\x15\n\rreserved_gpus\x18\n \x01(\x02\"A\n\x17ShowCreateFilterRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x18ShowCreateFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"@\n\x16ShowCreateOwnerRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x17ShowCreateOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"_\n ShowCreateServiceOverrideRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12!\n\x07service\x18\x02 \x01(\x0b\x32\x10.service.Service\"W\n!ShowCreateServiceOverrideResponse\x12\x32\n\x10service_override\x18\x01 \x01(\x0b\x32\x18.service.ServiceOverride\"%\n\x15ShowCreateShowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"2\n\x16ShowCreateShowResponse\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"m\n\x1dShowCreateSubscriptionRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x02\x12\r\n\x05\x62urst\x18\x04 \x01(\x02\"R\n\x1eShowCreateSubscriptionResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"-\n\x11ShowDeleteRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"\x14\n\x12ShowDeleteResponse\"E\n\x18ShowEnableBookingRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1b\n\x19ShowEnableBookingResponse\"I\n\x1cShowEnableDispatchingRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1f\n\x1dShowEnableDispatchingResponse\"?\n\x15ShowFindFilterRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"8\n\x16ShowFindFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"#\n\x13ShowFindShowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x14ShowFindShowResponse\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"\x1b\n\x19ShowGetActiveShowsRequest\":\n\x1aShowGetActiveShowsResponse\x12\x1c\n\x05shows\x18\x01 \x01(\x0b\x32\r.show.ShowSeq\"/\n\x13ShowGetDeedsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"4\n\x14ShowGetDeedsResponse\x12\x1c\n\x05\x64\x65\x65\x64s\x18\x01 \x01(\x0b\x32\r.host.DeedSeq\"H\n\x18ShowGetDepartmentRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x12\n\ndepartment\x18\x02 \x01(\t\"G\n\x19ShowGetDepartmentResponse\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"5\n\x19ShowGetDepartmentsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"L\n\x1aShowGetDepartmentsResponse\x12.\n\x0b\x64\x65partments\x18\x01 \x01(\x0b\x32\x19.department.DepartmentSeq\"1\n\x15ShowGetFiltersRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"<\n\x16ShowGetFiltersResponse\x12\"\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x11.filter.FilterSeq\"0\n\x14ShowGetGroupsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"6\n\x15ShowGetGroupsResponse\x12\x1d\n\x06groups\x18\x01 \x01(\x0b\x32\r.job.GroupSeq\".\n\x12ShowGetJobsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"0\n\x13ShowGetJobsResponse\x12\x19\n\x04jobs\x18\x01 \x01(\x0b\x32\x0b.job.JobSeq\"7\n\x1bShowGetJobWhiteboardRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"D\n\x1cShowGetJobWhiteboardResponse\x12$\n\nwhiteboard\x18\x01 \x01(\x0b\x32\x10.job.NestedGroup\"3\n\x17ShowGetRootGroupRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"5\n\x18ShowGetRootGroupResponse\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"G\n\x1dShowGetServiceOverrideRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"T\n\x1eShowGetServiceOverrideResponse\x12\x32\n\x10service_override\x18\x01 \x01(\x0b\x32\x18.service.ServiceOverride\":\n\x1eShowGetServiceOverridesRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"Y\n\x1fShowGetServiceOverridesResponse\x12\x36\n\x11service_overrides\x18\x01 \x01(\x0b\x32\x1b.service.ServiceOverrideSeq\"\x15\n\x13ShowGetShowsRequest\"4\n\x14ShowGetShowsResponse\x12\x1c\n\x05shows\x18\x01 \x01(\x0b\x32\r.show.ShowSeq\"6\n\x1aShowGetSubscriptionRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"S\n\x1bShowGetSubscriptionResponse\x12\x34\n\rsubscriptions\x18\x01 \x01(\x0b\x32\x1d.subscription.SubscriptionSeq\"?\n\x14ShowSetActiveRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\r\n\x05value\x18\x02 \x01(\x08\"\x17\n\x15ShowSetActiveResponse\"E\n\x1aShowSetCommentEmailRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x1d\n\x1bShowSetCommentEmailResponse\"L\n\x1dShowSetDefaultMaxCoresRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x11\n\tmax_cores\x18\x02 \x01(\x02\" \n\x1eShowSetDefaultMaxCoresResponse\"L\n\x1dShowSetDefaultMinCoresRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x11\n\tmin_cores\x18\x02 \x01(\x02\" \n\x1eShowSetDefaultMinCoresResponse\"J\n\x1cShowSetDefaultMaxGpusRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x10\n\x08max_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dShowSetDefaultMaxGpusResponse\"J\n\x1cShowSetDefaultMinGpusRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x10\n\x08min_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dShowSetDefaultMinGpusResponse\"H\n\x12ShowArchiveRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x18\n\x10target_show_name\x18\x02 \x01(\t\"\x15\n\x13ShowArchiveResponse2\xac\x13\n\rShowInterface\x12M\n\x0c\x43reateFilter\x12\x1d.show.ShowCreateFilterRequest\x1a\x1e.show.ShowCreateFilterResponse\x12J\n\x0b\x43reateOwner\x12\x1c.show.ShowCreateOwnerRequest\x1a\x1d.show.ShowCreateOwnerResponse\x12h\n\x15\x43reateServiceOverride\x12&.show.ShowCreateServiceOverrideRequest\x1a\'.show.ShowCreateServiceOverrideResponse\x12G\n\nCreateShow\x12\x1b.show.ShowCreateShowRequest\x1a\x1c.show.ShowCreateShowResponse\x12_\n\x12\x43reateSubscription\x12#.show.ShowCreateSubscriptionRequest\x1a$.show.ShowCreateSubscriptionResponse\x12;\n\x06\x44\x65lete\x12\x17.show.ShowDeleteRequest\x1a\x18.show.ShowDeleteResponse\x12P\n\rEnableBooking\x12\x1e.show.ShowEnableBookingRequest\x1a\x1f.show.ShowEnableBookingResponse\x12\\\n\x11\x45nableDispatching\x12\".show.ShowEnableDispatchingRequest\x1a#.show.ShowEnableDispatchingResponse\x12G\n\nFindFilter\x12\x1b.show.ShowFindFilterRequest\x1a\x1c.show.ShowFindFilterResponse\x12\x41\n\x08\x46indShow\x12\x19.show.ShowFindShowRequest\x1a\x1a.show.ShowFindShowResponse\x12S\n\x0eGetActiveShows\x12\x1f.show.ShowGetActiveShowsRequest\x1a .show.ShowGetActiveShowsResponse\x12\x41\n\x08GetDeeds\x12\x19.show.ShowGetDeedsRequest\x1a\x1a.show.ShowGetDeedsResponse\x12P\n\rGetDepartment\x12\x1e.show.ShowGetDepartmentRequest\x1a\x1f.show.ShowGetDepartmentResponse\x12S\n\x0eGetDepartments\x12\x1f.show.ShowGetDepartmentsRequest\x1a .show.ShowGetDepartmentsResponse\x12G\n\nGetFilters\x12\x1b.show.ShowGetFiltersRequest\x1a\x1c.show.ShowGetFiltersResponse\x12\x44\n\tGetGroups\x12\x1a.show.ShowGetGroupsRequest\x1a\x1b.show.ShowGetGroupsResponse\x12>\n\x07GetJobs\x12\x18.show.ShowGetJobsRequest\x1a\x19.show.ShowGetJobsResponse\x12Y\n\x10GetJobWhiteboard\x12!.show.ShowGetJobWhiteboardRequest\x1a\".show.ShowGetJobWhiteboardResponse\x12M\n\x0cGetRootGroup\x12\x1d.show.ShowGetRootGroupRequest\x1a\x1e.show.ShowGetRootGroupResponse\x12_\n\x12GetServiceOverride\x12#.show.ShowGetServiceOverrideRequest\x1a$.show.ShowGetServiceOverrideResponse\x12\x62\n\x13GetServiceOverrides\x12$.show.ShowGetServiceOverridesRequest\x1a%.show.ShowGetServiceOverridesResponse\x12\x41\n\x08GetShows\x12\x19.show.ShowGetShowsRequest\x1a\x1a.show.ShowGetShowsResponse\x12W\n\x10GetSubscriptions\x12 .show.ShowGetSubscriptionRequest\x1a!.show.ShowGetSubscriptionResponse\x12\x44\n\tSetActive\x12\x1a.show.ShowSetActiveRequest\x1a\x1b.show.ShowSetActiveResponse\x12V\n\x0fSetCommentEmail\x12 .show.ShowSetCommentEmailRequest\x1a!.show.ShowSetCommentEmailResponse\x12_\n\x12SetDefaultMaxCores\x12#.show.ShowSetDefaultMaxCoresRequest\x1a$.show.ShowSetDefaultMaxCoresResponse\x12_\n\x12SetDefaultMinCores\x12#.show.ShowSetDefaultMinCoresRequest\x1a$.show.ShowSetDefaultMinCoresResponse\x12\\\n\x11SetDefaultMaxGpus\x12\".show.ShowSetDefaultMaxGpusRequest\x1a#.show.ShowSetDefaultMaxGpusResponse\x12\\\n\x11SetDefaultMinGpus\x12\".show.ShowSetDefaultMinGpusRequest\x1a#.show.ShowSetDefaultMinGpusResponse\x12>\n\x07\x41rchive\x12\x18.show.ShowArchiveRequest\x1a\x19.show.ShowArchiveResponseB:\n\x1e\x63om.imageworks.spcue.grpc.showP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'show_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.showP\001Z\026opencue_gateway/gen/go'
  _globals['_SHOW']._serialized_start=111
  _globals['_SHOW']._serialized_end=376
  _globals['_SHOWSEQ']._serialized_start=378
  _globals['_SHOWSEQ']._serialized_end=414
  _globals['_SHOWSTATS']._serialized_start=417
  _globals['_SHOWSTATS']._serialized_end=680
  _globals['_SHOWCREATEFILTERREQUEST']._serialized_start=682
  _globals['_SHOWCREATEFILTERREQUEST']._serialized_end=747
  _globals['_SHOWCREATEFILTERRESPONSE']._serialized_start=749
  _globals['_SHOWCREATEFILTERRESPONSE']._serialized_end=807
  _globals['_SHOWCREATEOWNERREQUEST']._serialized_start=809
  _globals['_SHOWCREATEOWNERREQUEST']._serialized_end=873
  _globals['_SHOWCREATEOWNERRESPONSE']._serialized_start=875
  _globals['_SHOWCREATEOWNERRESPONSE']._serialized_end=928
  _globals['_SHOWCREATESERVICEOVERRIDEREQUEST']._serialized_start=930
  _globals['_SHOWCREATESERVICEOVERRIDEREQUEST']._serialized_end=1025
  _globals['_SHOWCREATESERVICEOVERRIDERESPONSE']._serialized_start=1027
  _globals['_SHOWCREATESERVICEOVERRIDERESPONSE']._serialized_end=1114
  _globals['_SHOWCREATESHOWREQUEST']._serialized_start=1116
  _globals['_SHOWCREATESHOWREQUEST']._serialized_end=1153
  _globals['_SHOWCREATESHOWRESPONSE']._serialized_start=1155
  _globals['_SHOWCREATESHOWRESPONSE']._serialized_end=1205
  _globals['_SHOWCREATESUBSCRIPTIONREQUEST']._serialized_start=1207
  _globals['_SHOWCREATESUBSCRIPTIONREQUEST']._serialized_end=1316
  _globals['_SHOWCREATESUBSCRIPTIONRESPONSE']._serialized_start=1318
  _globals['_SHOWCREATESUBSCRIPTIONRESPONSE']._serialized_end=1400
  _globals['_SHOWDELETEREQUEST']._serialized_start=1402
  _globals['_SHOWDELETEREQUEST']._serialized_end=1447
  _globals['_SHOWDELETERESPONSE']._serialized_start=1449
  _globals['_SHOWDELETERESPONSE']._serialized_end=1469
  _globals['_SHOWENABLEBOOKINGREQUEST']._serialized_start=1471
  _globals['_SHOWENABLEBOOKINGREQUEST']._serialized_end=1540
  _globals['_SHOWENABLEBOOKINGRESPONSE']._serialized_start=1542
  _globals['_SHOWENABLEBOOKINGRESPONSE']._serialized_end=1569
  _globals['_SHOWENABLEDISPATCHINGREQUEST']._serialized_start=1571
  _globals['_SHOWENABLEDISPATCHINGREQUEST']._serialized_end=1644
  _globals['_SHOWENABLEDISPATCHINGRESPONSE']._serialized_start=1646
  _globals['_SHOWENABLEDISPATCHINGRESPONSE']._serialized_end=1677
  _globals['_SHOWFINDFILTERREQUEST']._serialized_start=1679
  _globals['_SHOWFINDFILTERREQUEST']._serialized_end=1742
  _globals['_SHOWFINDFILTERRESPONSE']._serialized_start=1744
  _globals['_SHOWFINDFILTERRESPONSE']._serialized_end=1800
  _globals['_SHOWFINDSHOWREQUEST']._serialized_start=1802
  _globals['_SHOWFINDSHOWREQUEST']._serialized_end=1837
  _globals['_SHOWFINDSHOWRESPONSE']._serialized_start=1839
  _globals['_SHOWFINDSHOWRESPONSE']._serialized_end=1887
  _globals['_SHOWGETACTIVESHOWSREQUEST']._serialized_start=1889
  _globals['_SHOWGETACTIVESHOWSREQUEST']._serialized_end=1916
  _globals['_SHOWGETACTIVESHOWSRESPONSE']._serialized_start=1918
  _globals['_SHOWGETACTIVESHOWSRESPONSE']._serialized_end=1976
  _globals['_SHOWGETDEEDSREQUEST']._serialized_start=1978
  _globals['_SHOWGETDEEDSREQUEST']._serialized_end=2025
  _globals['_SHOWGETDEEDSRESPONSE']._serialized_start=2027
  _globals['_SHOWGETDEEDSRESPONSE']._serialized_end=2079
  _globals['_SHOWGETDEPARTMENTREQUEST']._serialized_start=2081
  _globals['_SHOWGETDEPARTMENTREQUEST']._serialized_end=2153
  _globals['_SHOWGETDEPARTMENTRESPONSE']._serialized_start=2155
  _globals['_SHOWGETDEPARTMENTRESPONSE']._serialized_end=2226
  _globals['_SHOWGETDEPARTMENTSREQUEST']._serialized_start=2228
  _globals['_SHOWGETDEPARTMENTSREQUEST']._serialized_end=2281
  _globals['_SHOWGETDEPARTMENTSRESPONSE']._serialized_start=2283
  _globals['_SHOWGETDEPARTMENTSRESPONSE']._serialized_end=2359
  _globals['_SHOWGETFILTERSREQUEST']._serialized_start=2361
  _globals['_SHOWGETFILTERSREQUEST']._serialized_end=2410
  _globals['_SHOWGETFILTERSRESPONSE']._serialized_start=2412
  _globals['_SHOWGETFILTERSRESPONSE']._serialized_end=2472
  _globals['_SHOWGETGROUPSREQUEST']._serialized_start=2474
  _globals['_SHOWGETGROUPSREQUEST']._serialized_end=2522
  _globals['_SHOWGETGROUPSRESPONSE']._serialized_start=2524
  _globals['_SHOWGETGROUPSRESPONSE']._serialized_end=2578
  _globals['_SHOWGETJOBSREQUEST']._serialized_start=2580
  _globals['_SHOWGETJOBSREQUEST']._serialized_end=2626
  _globals['_SHOWGETJOBSRESPONSE']._serialized_start=2628
  _globals['_SHOWGETJOBSRESPONSE']._serialized_end=2676
  _globals['_SHOWGETJOBWHITEBOARDREQUEST']._serialized_start=2678
  _globals['_SHOWGETJOBWHITEBOARDREQUEST']._serialized_end=2733
  _globals['_SHOWGETJOBWHITEBOARDRESPONSE']._serialized_start=2735
  _globals['_SHOWGETJOBWHITEBOARDRESPONSE']._serialized_end=2803
  _globals['_SHOWGETROOTGROUPREQUEST']._serialized_start=2805
  _globals['_SHOWGETROOTGROUPREQUEST']._serialized_end=2856
  _globals['_SHOWGETROOTGROUPRESPONSE']._serialized_start=2858
  _globals['_SHOWGETROOTGROUPRESPONSE']._serialized_end=2911
  _globals['_SHOWGETSERVICEOVERRIDEREQUEST']._serialized_start=2913
  _globals['_SHOWGETSERVICEOVERRIDEREQUEST']._serialized_end=2984
  _globals['_SHOWGETSERVICEOVERRIDERESPONSE']._serialized_start=2986
  _globals['_SHOWGETSERVICEOVERRIDERESPONSE']._serialized_end=3070
  _globals['_SHOWGETSERVICEOVERRIDESREQUEST']._serialized_start=3072
  _globals['_SHOWGETSERVICEOVERRIDESREQUEST']._serialized_end=3130
  _globals['_SHOWGETSERVICEOVERRIDESRESPONSE']._serialized_start=3132
  _globals['_SHOWGETSERVICEOVERRIDESRESPONSE']._serialized_end=3221
  _globals['_SHOWGETSHOWSREQUEST']._serialized_start=3223
  _globals['_SHOWGETSHOWSREQUEST']._serialized_end=3244
  _globals['_SHOWGETSHOWSRESPONSE']._serialized_start=3246
  _globals['_SHOWGETSHOWSRESPONSE']._serialized_end=3298
  _globals['_SHOWGETSUBSCRIPTIONREQUEST']._serialized_start=3300
  _globals['_SHOWGETSUBSCRIPTIONREQUEST']._serialized_end=3354
  _globals['_SHOWGETSUBSCRIPTIONRESPONSE']._serialized_start=3356
  _globals['_SHOWGETSUBSCRIPTIONRESPONSE']._serialized_end=3439
  _globals['_SHOWSETACTIVEREQUEST']._serialized_start=3441
  _globals['_SHOWSETACTIVEREQUEST']._serialized_end=3504
  _globals['_SHOWSETACTIVERESPONSE']._serialized_start=3506
  _globals['_SHOWSETACTIVERESPONSE']._serialized_end=3529
  _globals['_SHOWSETCOMMENTEMAILREQUEST']._serialized_start=3531
  _globals['_SHOWSETCOMMENTEMAILREQUEST']._serialized_end=3600
  _globals['_SHOWSETCOMMENTEMAILRESPONSE']._serialized_start=3602
  _globals['_SHOWSETCOMMENTEMAILRESPONSE']._serialized_end=3631
  _globals['_SHOWSETDEFAULTMAXCORESREQUEST']._serialized_start=3633
  _globals['_SHOWSETDEFAULTMAXCORESREQUEST']._serialized_end=3709
  _globals['_SHOWSETDEFAULTMAXCORESRESPONSE']._serialized_start=3711
  _globals['_SHOWSETDEFAULTMAXCORESRESPONSE']._serialized_end=3743
  _globals['_SHOWSETDEFAULTMINCORESREQUEST']._serialized_start=3745
  _globals['_SHOWSETDEFAULTMINCORESREQUEST']._serialized_end=3821
  _globals['_SHOWSETDEFAULTMINCORESRESPONSE']._serialized_start=3823
  _globals['_SHOWSETDEFAULTMINCORESRESPONSE']._serialized_end=3855
  _globals['_SHOWSETDEFAULTMAXGPUSREQUEST']._serialized_start=3857
  _globals['_SHOWSETDEFAULTMAXGPUSREQUEST']._serialized_end=3931
  _globals['_SHOWSETDEFAULTMAXGPUSRESPONSE']._serialized_start=3933
  _globals['_SHOWSETDEFAULTMAXGPUSRESPONSE']._serialized_end=3964
  _globals['_SHOWSETDEFAULTMINGPUSREQUEST']._serialized_start=3966
  _globals['_SHOWSETDEFAULTMINGPUSREQUEST']._serialized_end=4040
  _globals['_SHOWSETDEFAULTMINGPUSRESPONSE']._serialized_start=4042
  _globals['_SHOWSETDEFAULTMINGPUSRESPONSE']._serialized_end=4073
  _globals['_SHOWARCHIVEREQUEST']._serialized_start=4075
  _globals['_SHOWARCHIVEREQUEST']._serialized_end=4147
  _globals['_SHOWARCHIVERESPONSE']._serialized_start=4149
  _globals['_SHOWARCHIVERESPONSE']._serialized_end=4170
  _globals['_SHOWINTERFACE']._serialized_start=4173
  _globals['_SHOWINTERFACE']._serialized_end=6649
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: depend.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x65pend.proto\x12\x06\x64\x65pend\"\x91\x02\n\x06\x44\x65pend\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.depend.DependType\x12$\n\x06target\x18\x03 \x01(\x0e\x32\x14.depend.DependTarget\x12\x11\n\tany_frame\x18\x04 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x15\n\rdepend_er_job\x18\x06 \x01(\t\x12\x17\n\x0f\x64\x65pend_er_layer\x18\x07 \x01(\t\x12\x17\n\x0f\x64\x65pend_er_frame\x18\x08 \x01(\t\x12\x15\n\rdepend_on_job\x18\t \x01(\t\x12\x17\n\x0f\x64\x65pend_on_layer\x18\n \x01(\t\x12\x17\n\x0f\x64\x65pend_on_frame\x18\x0b \x01(\t\",\n\tDependSeq\x12\x1f\n\x07\x64\x65pends\x18\x01 \x03(\x0b\x32\x0e.depend.Depend\"$\n\x16\x44\x65pendGetDependRequest\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x17\x44\x65pendGetDependResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"6\n\x14\x44\x65pendSatisfyRequest\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"\x17\n\x15\x44\x65pendSatisfyResponse\"8\n\x16\x44\x65pendUnsatisfyRequest\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"\x19\n\x17\x44\x65pendUnsatisfyResponse*\xf4\x01\n\nDependType\x12\x0e\n\nJOB_ON_JOB\x10\x00\x12\x10\n\x0cJOB_ON_LAYER\x10\x01\x12\x10\n\x0cJOB_ON_FRAME\x10\x02\x12\x10\n\x0cLAYER_ON_JOB\x10\x03\x12\x12\n\x0eLAYER_ON_LAYER\x10\x04\x12\x12\n\x0eLAYER_ON_FRAME\x10\x05\x12\x10\n\x0c\x46RAME_ON_JOB\x10\x06\x12\x12\n\x0e\x46RAME_ON_LAYER\x10\x07\x12\x12\n\x0e\x46RAME_ON_FRAME\x10\x08\x12\x12\n\x0e\x46RAME_BY_FRAME\x10\t\x12\x12\n\x0ePREVIOUS_FRAME\x10\n\x12\x16\n\x12LAYER_ON_SIM_FRAME\x10\x0b*:\n\x0c\x44\x65pendTarget\x12\x0c\n\x08INTERNAL\x10\x00\x12\x0c\n\x08\x45XTERNAL\x10\x01\x12\x0e\n\nANY_TARGET\x10\x02\x32\xf5\x01\n\x0f\x44\x65pendInterface\x12L\n\tGetDepend\x12\x1e.depend.DependGetDependRequest\x1a\x1f.depend.DependGetDependResponse\x12\x46\n\x07Satisfy\x12\x1c.depend.DependSatisfyRequest\x1a\x1d.depend.DependSatisfyResponse\x12L\n\tUnsatisfy\x12\x1e.depend.DependUnsatisfyRequest\x1a\x1f.depend.DependUnsatisfyResponseB<\n com.imageworks.spcue.grpc.dependP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'depend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.dependP\001Z\026opencue_gateway/gen/go'
  _globals['_DEPENDTYPE']._serialized_start=610
  _globals['_DEPENDTYPE']._serialized_end=854
  _globals['_DEPENDTARGET']._serialized_start=856
  _globals['_DEPENDTARGET']._serialized_end=914
  _globals['_DEPEND']._serialized_start=25
  _globals['_DEPEND']._serialized_end=298
  _globals['_DEPENDSEQ']._serialized_start=300
  _globals['_DEPENDSEQ']._serialized_end=344
  _globals['_DEPENDGETDEPENDREQUEST']._serialized_start=346
  _globals['_DEPENDGETDEPENDREQUEST']._serialized_end=382
  _globals['_DEPENDGETDEPENDRESPONSE']._serialized_start=384
  _globals['_DEPENDGETDEPENDRESPONSE']._serialized_end=441
  _globals['_DEPENDSATISFYREQUEST']._serialized_start=443
  _globals['_DEPENDSATISFYREQUEST']._serialized_end=497
  _globals['_DEPENDSATISFYRESPONSE']._serialized_start=499
  _globals['_DEPENDSATISFYRESPONSE']._serialized_end=522
  _globals['_DEPENDUNSATISFYREQUEST']._serialized_start=524
  _globals['_DEPENDUNSATISFYREQUEST']._serialized_end=580
  _globals['_DEPENDUNSATISFYRESPONSE']._serialized_start=582
  _globals['_DEPENDUNSATISFYRESPONSE']._serialized_end=607
  _globals['_DEPENDINTERFACE']._serialized_start=917
  _globals['_DEPENDINTERFACE']._serialized_end=1162
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: limit.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0blimit.proto\x12\x05limit\"M\n\x05Limit\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmax_value\x18\x03 \x01(\x05\x12\x17\n\x0f\x63urrent_running\x18\x04 \x01(\x05\"5\n\x12LimitCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmax_value\x18\x02 \x01(\x05\"2\n\x13LimitCreateResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\"\n\x12LimitDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x15\n\x13LimitDeleteResponse\" \n\x10LimitFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x11LimitFindResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\x1d\n\x0fLimitGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x10LimitGetResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\x14\n\x12LimitGetAllRequest\"3\n\x13LimitGetAllResponse\x12\x1c\n\x06limits\x18\x01 \x03(\x0b\x32\x0c.limit.Limit\"8\n\x12LimitRenameRequest\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x15\n\x13LimitRenameResponse\":\n\x17LimitSetMaxValueRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmax_value\x18\x02 \x01(\x05\"\x1a\n\x18LimitSetMaxValueResponse2\xd7\x03\n\x0eLimitInterface\x12?\n\x06\x43reate\x12\x19.limit.LimitCreateRequest\x1a\x1a.limit.LimitCreateResponse\x12?\n\x06\x44\x65lete\x12\x19.limit.LimitDeleteRequest\x1a\x1a.limit.LimitDeleteResponse\x12\x39\n\x04\x46ind\x12\x17.limit.LimitFindRequest\x1a\x18.limit.LimitFindResponse\x12\x36\n\x03Get\x12\x16.limit.LimitGetRequest\x1a\x17.limit.LimitGetResponse\x12?\n\x06GetAll\x12\x19.limit.LimitGetAllRequest\x1a\x1a.limit.LimitGetAllResponse\x12?\n\x06Rename\x12\x19.limit.LimitRenameRequest\x1a\x1a.limit.LimitRenameResponse\x12N\n\x0bSetMaxValue\x12\x1e.limit.LimitSetMaxValueRequest\x1a\x1f.limit.LimitSetMaxValueResponseB;\n\x1f\x63om.imageworks.spcue.grpc.limitP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.imageworks.spcue.grpc.limitP\001Z\026opencue_gateway/gen/go'
  _globals['_LIMIT']._serialized_start=22
  _globals['_LIMIT']._serialized_end=99
  _globals['_LIMITCREATEREQUEST']._serialized_start=101
  _globals['_LIMITCREATEREQUEST']._serialized_end=154
  _globals['_LIMITCREATERESPONSE']._serialized_start=156
  _globals['_LIMITCREATERESPONSE']._serialized_end=206
  _globals['_LIMITDELETEREQUEST']._serialized_start=208
  _globals['_LIMITDELETEREQUEST']._serialized_end=242
  _globals['_LIMITDELETERESPONSE']._serialized_start=244
  _globals['_LIMITDELETERESPONSE']._serialized_end=265
  _globals['_LIMITFINDREQUEST']._serialized_start=267
  _globals['_LIMITFINDREQUEST']._serialized_end=299
  _globals['_LIMITFINDRESPONSE']._serialized_start=301
  _globals['_LIMITFINDRESPONSE']._serialized_end=349
  _globals['_LIMITGETREQUEST']._serialized_start=351
  _globals['_LIMITGETREQUEST']._serialized_end=380
  _globals['_LIMITGETRESPONSE']._serialized_start=382
  _globals['_LIMITGETRESPONSE']._serialized_end=429
  _globals['_LIMITGETALLREQUEST']._serialized_start=431
  _globals['_LIMITGETALLREQUEST']._serialized_end=451
  _globals['_LIMITGETALLRESPONSE']._serialized_start=453
  _globals['_LIMITGETALLRESPONSE']._serialized_end=504
  _globals['_LIMITRENAMEREQUEST']._serialized_start=506
  _globals['_LIMITRENAMEREQUEST']._serialized_end=562
  _globals['_LIMITRENAMERESPONSE']._serialized_start=564
  _globals['_LIMITRENAMERESPONSE']._serialized_end=585
  _globals['_LIMITSETMAXVALUEREQUEST']._serialized_start=587
  _globals['_LIMITSETMAXVALUEREQUEST']._serialized_end=645
  _globals['_LIMITSETMAXVALUERESPONSE']._serialized_start=647
  _globals['_LIMITSETMAXVALUERESPONSE']._serialized_end=673
  _globals['_LIMITINTERFACE']._serialized_start=676
  _globals['_LIMITINTERFACE']._serialized_end=1147
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import comment_pb2 as comment__pb2


class CommentInterfaceStub(object):
    """The Comment class contains comment data for any entity that supports
    commenting.  Currently these are [Job] and [Host].

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/comment.CommentInterface/Delete',
                request_serializer=comment__pb2.CommentDeleteRequest.SerializeToString,
                response_deserializer=comment__pb2.CommentDeleteResponse.FromString,
                )
        self.Save = channel.unary_unary(
                '/comment.CommentInterface/Save',
                request_serializer=comment__pb2.CommentSaveRequest.SerializeToString,
                response_deserializer=comment__pb2.CommentSaveResponse.FromString,
                )


class CommentInterfaceServicer(object):
    """The Comment class contains comment data for any entity that supports
    commenting.  Currently these are [Job] and [Host].

    -------- Services --------]

    """

    def Delete(self, request, context):
        """Delete the specified comment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Save(self, request, context):
        """Saves the specified comment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CommentInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=comment__pb2.CommentDeleteRequest.FromString,
                    response_serializer=comment__pb2.CommentDeleteResponse.SerializeToString,
            ),
            'Save': grpc.unary_unary_rpc_method_handler(
                    servicer.Save,
                    request_deserializer=comment__pb2.CommentSaveRequest.FromString,
                    response_serializer=comment__pb2.CommentSaveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'comment.CommentInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CommentInterface(object):
    """The Comment class contains comment data for any entity that supports
    commenting.  Currently these are [Job] and [Host].

    -------- Services --------]

    """

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/comment.CommentInterface/Delete',
            comment__pb2.CommentDeleteRequest.SerializeToString,
            comment__pb2.CommentDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Save(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/comment.CommentInterface/Save',
            comment__pb2.CommentSaveRequest.SerializeToString,
            comment__pb2.CommentSaveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import renderPartition_pb2 as renderPartition__pb2


class RenderPartitionInterfaceStub(object):
    """-------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/renderPartition.RenderPartitionInterface/Delete',
                request_serializer=renderPartition__pb2.RenderPartDeleteRequest.SerializeToString,
                response_deserializer=renderPartition__pb2.RenderPartDeleteResponse.FromString,
                )
        self.SetMaxResources = channel.unary_unary(
                '/renderPartition.RenderPartitionInterface/SetMaxResources',
                request_serializer=renderPartition__pb2.RenderPartSetMaxResourcesRequest.SerializeToString,
                response_deserializer=renderPartition__pb2.RenderPartSetMaxResourcesResponse.FromString,
                )


class RenderPartitionInterfaceServicer(object):
    """-------- Services --------]

    """

    def Delete(self, request, context):
        """Deletes the host local setup.  Any proc that is running from this should be killed or else the counts
        could be off.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMaxResources(self, request, context):
        """Reset the maximum amount of cores and memory for this render partition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RenderPartitionInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=renderPartition__pb2.RenderPartDeleteRequest.FromString,
                    response_serializer=renderPartition__pb2.RenderPartDeleteResponse.SerializeToString,
            ),
            'SetMaxResources': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMaxResources,
                    request_deserializer=renderPartition__pb2.RenderPartSetMaxResourcesRequest.FromString,
                    response_serializer=renderPartition__pb2.RenderPartSetMaxResourcesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'renderPartition.RenderPartitionInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RenderPartitionInterface(object):
    """-------- Services --------]

    """

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/renderPartition.RenderPartitionInterface/Delete',
            renderPartition__pb2.RenderPartDeleteRequest.SerializeToString,
            renderPartition__pb2.RenderPartDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMaxResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/renderPartition.RenderPartitionInterface/SetMaxResources',
            renderPartition__pb2.RenderPartSetMaxResourcesRequest.SerializeToString,
            renderPartition__pb2.RenderPartSetMaxResourcesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: host.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import comment_pb2 as comment__pb2
from . import criterion_pb2 as criterion__pb2
from . import job_pb2 as job__pb2
from . import renderPartition_pb2 as renderPartition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nhost.proto\x12\x04host\x1a\rcomment.proto\x1a\x0f\x63riterion.proto\x1a\tjob.proto\x1a\x15renderPartition.proto\"=\n\x04\x44\x65\x65\x64\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04show\x18\x04 \x01(\t\"$\n\x07\x44\x65\x65\x64Seq\x12\x19\n\x05\x64\x65\x65\x64s\x18\x01 \x03(\x0b\x32\n.host.Deed\"6\n\x10HardwareStateSeq\x12\"\n\x05state\x18\x01 \x03(\x0e\x32\x13.host.HardwareState\".\n\x0cLockStateSeq\x12\x1e\n\x05state\x18\x01 \x03(\x0e\x32\x0f.host.LockState\"\xde\x04\n\x04Host\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalloc_name\x18\x03 \x01(\t\x12\x15\n\rnimby_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bhas_comment\x18\x05 \x01(\x08\x12\r\n\x05\x63ores\x18\x06 \x01(\x02\x12\x12\n\nidle_cores\x18\x07 \x01(\x02\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x13\n\x0bidle_memory\x18\t \x01(\x03\x12\x12\n\ngpu_memory\x18\n \x01(\x03\x12\x17\n\x0fidle_gpu_memory\x18\x0b \x01(\x03\x12\x12\n\ntotal_swap\x18\x0c \x01(\x03\x12\x14\n\x0ctotal_memory\x18\r \x01(\x03\x12\x18\n\x10total_gpu_memory\x18\x0e \x01(\x03\x12\x11\n\ttotal_mcp\x18\x0f \x01(\x03\x12\x11\n\tfree_swap\x18\x10 \x01(\x03\x12\x13\n\x0b\x66ree_memory\x18\x11 \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x12 \x01(\x03\x12\x17\n\x0f\x66ree_gpu_memory\x18\x13 \x01(\x03\x12\x0c\n\x04load\x18\x14 \x01(\x05\x12\x11\n\tboot_time\x18\x15 \x01(\x05\x12\x11\n\tping_time\x18\x16 \x01(\x05\x12\n\n\x02os\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\"\n\x05state\x18\x19 \x01(\x0e\x32\x13.host.HardwareState\x12#\n\nlock_state\x18\x1a \x01(\x0e\x32\x0f.host.LockState\x12%\n\x0bthread_mode\x18\x1b \x01(\x0e\x32\x10.host.ThreadMode\x12\x0c\n\x04gpus\x18\x1c \x01(\x02\x12\x11\n\tidle_gpus\x18\x1d \x01(\x02\"\xb0\x01\n\x12HostSearchCriteria\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\r\n\x05regex\x18\x02 \x03(\t\x12\x0e\n\x06substr\x18\x03 \x03(\t\x12\x0b\n\x03ids\x18\x04 \x03(\t\x12\x0e\n\x06\x61llocs\x18\x05 \x03(\t\x12&\n\x06states\x18\x06 \x01(\x0b\x32\x16.host.HardwareStateSeq\x12\'\n\x0block_states\x18\x07 \x01(\x0b\x32\x12.host.LockStateSeq\"$\n\x07HostSeq\x12\x19\n\x05hosts\x18\x01 \x03(\x0b\x32\n.host.Host\"\x88\x05\n\nNestedHost\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalloc_name\x18\x03 \x01(\t\x12\x15\n\rnimby_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bhas_comment\x18\x05 \x01(\x08\x12\r\n\x05\x63ores\x18\x06 \x01(\x02\x12\x12\n\nidle_cores\x18\x07 \x01(\x02\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x13\n\x0bidle_memory\x18\t \x01(\x03\x12\x12\n\ngpu_memory\x18\n \x01(\x03\x12\x17\n\x0fidle_gpu_memory\x18\x0b \x01(\x03\x12\x12\n\ntotal_swap\x18\x0c \x01(\x03\x12\x14\n\x0ctotal_memory\x18\r \x01(\x03\x12\x18\n\x10total_gpu_memory\x18\x0e \x01(\x03\x12\x11\n\ttotal_mcp\x18\x0f \x01(\x03\x12\x11\n\tfree_swap\x18\x10 \x01(\x03\x12\x13\n\x0b\x66ree_memory\x18\x11 \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x12 \x01(\x03\x12\x17\n\x0f\x66ree_gpu_memory\x18\x13 \x01(\x03\x12\x0c\n\x04load\x18\x14 \x01(\x05\x12\x11\n\tboot_time\x18\x15 \x01(\x05\x12\x11\n\tping_time\x18\x16 \x01(\x05\x12\n\n\x02os\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\"\n\x05state\x18\x19 \x01(\x0e\x32\x13.host.HardwareState\x12#\n\nlock_state\x18\x1a \x01(\x0e\x32\x0f.host.LockState\x12%\n\x0bthread_mode\x18\x1b \x01(\x0e\x32\x10.host.ThreadMode\x12\"\n\x05procs\x18\x1c \x01(\x0b\x32\x13.host.NestedProcSeq\x12\x0c\n\x04gpus\x18\x1d \x01(\x02\x12\x11\n\tidle_gpus\x18\x1e \x01(\x02\"7\n\rNestedHostSeq\x12&\n\x0cnested_hosts\x18\x01 \x03(\x0b\x32\x10.host.NestedHost\"\xb5\x03\n\nNestedProc\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08job_name\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x11\n\tping_time\x18\x07 \x01(\x05\x12\x12\n\nbookedTime\x18\x08 \x01(\x05\x12\x15\n\rdispatch_time\x18\t \x01(\x05\x12\x17\n\x0freserved_memory\x18\n \x01(\x03\x12\x1b\n\x13reserved_gpu_memory\x18\x0b \x01(\x03\x12\x13\n\x0bused_memory\x18\x0c \x01(\x03\x12\x16\n\x0ereserved_cores\x18\r \x01(\x02\x12\x10\n\x08unbooked\x18\x0e \x01(\x08\x12\x10\n\x08log_path\x18\x0f \x01(\t\x12\x17\n\x0fredirect_target\x18\x10 \x01(\t\x12\x10\n\x08services\x18\x11 \x03(\t\x12 \n\x06parent\x18\x12 \x01(\x0b\x32\x10.host.NestedHost\x12\x17\n\x0fused_gpu_memory\x18\x13 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x14 \x01(\x02\"7\n\rNestedProcSeq\x12&\n\x0cnested_procs\x18\x01 \x03(\x0b\x32\x10.host.NestedProc\"C\n\x05Owner\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04show\x18\x03 \x01(\t\x12\x12\n\nhost_count\x18\x04 \x01(\x05\"\xa6\x03\n\x04Proc\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08job_name\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x11\n\tping_time\x18\x07 \x01(\x05\x12\x12\n\nbookedTime\x18\x08 \x01(\x05\x12\x15\n\rdispatch_time\x18\t \x01(\x05\x12\x17\n\x0freserved_memory\x18\n \x01(\x03\x12\x1b\n\x13reserved_gpu_memory\x18\x0b \x01(\x03\x12\x13\n\x0bused_memory\x18\x0c \x01(\x03\x12\x16\n\x0ereserved_cores\x18\r \x01(\x02\x12\x10\n\x08unbooked\x18\x0e \x01(\x08\x12\x10\n\x08log_path\x18\x0f \x01(\t\x12\x17\n\x0fredirect_target\x18\x10 \x01(\t\x12\x10\n\x08services\x18\x11 \x03(\t\x12\x17\n\x0fused_gpu_memory\x18\x12 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x13 \x01(\x02\x12\x17\n\x0f\x63hild_processes\x18\x14 \x01(\x0c\"\xa0\x03\n\x12ProcSearchCriteria\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x0c\n\x04jobs\x18\x02 \x03(\t\x12\x0e\n\x06layers\x18\x03 \x03(\t\x12\r\n\x05shows\x18\x04 \x03(\t\x12\x0e\n\x06\x61llocs\x18\x05 \x03(\t\x12>\n\x0cmemory_range\x18\x06 \x03(\x0b\x32(.criterion.InRangeIntegerSearchCriterion\x12I\n\x13memory_greater_than\x18\n \x03(\x0b\x32,.criterion.GreaterThanIntegerSearchCriterion\x12\x46\n\x10memory_less_than\x18\x0b \x03(\x0b\x32,.criterion.GreaterThanIntegerSearchCriterion\x12@\n\x0e\x64uration_range\x18\x07 \x03(\x0b\x32(.criterion.InRangeIntegerSearchCriterion\x12\x13\n\x0bmax_results\x18\x08 \x03(\x05\x12\x14\n\x0c\x66irst_result\x18\t \x01(\x05\"$\n\x07ProcSeq\x12\x19\n\x05procs\x18\x01 \x03(\x0b\x32\n.host.Proc\"-\n\x11\x44\x65\x65\x64\x44\x65leteRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"\x14\n\x12\x44\x65\x65\x64\x44\x65leteResponse\".\n\x12\x44\x65\x65\x64GetHostRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"/\n\x13\x44\x65\x65\x64GetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"/\n\x13\x44\x65\x65\x64GetOwnerRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"2\n\x14\x44\x65\x65\x64GetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"X\n\x15HostAddCommentRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12%\n\x0bnew_comment\x18\x02 \x01(\x0b\x32\x10.comment.Comment\"\x18\n\x16HostAddCommentResponse\"<\n\x12HostAddTagsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x15\n\x13HostAddTagsResponse\"-\n\x11HostDeleteRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostDeleteResponse\"#\n\x13HostFindHostRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x14HostFindHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"2\n\x16HostGetCommentsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"@\n\x17HostGetCommentsResponse\x12%\n\x08\x63omments\x18\x01 \x01(\x0b\x32\x13.comment.CommentSeq\".\n\x12HostGetDeedRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"/\n\x13HostGetDeedResponse\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\" \n\x12HostGetHostRequest\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x13HostGetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\":\n\x13HostGetHostsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.HostSearchCriteria\"4\n\x14HostGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"\x1e\n\x1cHostGetHostWhiteboardRequest\"J\n\x1dHostGetHostWhiteboardResponse\x12)\n\x0cnested_hosts\x18\x01 \x01(\x0b\x32\x13.host.NestedHostSeq\"/\n\x13HostGetOwnerRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"2\n\x14HostGetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"/\n\x13HostGetProcsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"4\n\x14HostGetProcsResponse\x12\x1c\n\x05procs\x18\x01 \x01(\x0b\x32\r.host.ProcSeq\":\n\x1eHostGetRenderPartitionsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"a\n\x1fHostGetRenderPartitionsResponse\x12>\n\x11render_partitions\x18\x01 \x01(\x0b\x32#.renderPartition.RenderPartitionSeq\"+\n\x0fHostLockRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x12\n\x10HostLockResponse\"-\n\x11HostRebootRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostRebootResponse\"5\n\x19HostRebootWhenIdleRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x1c\n\x1aHostRebootWhenIdleResponse\"X\n\x18HostRedirectToJobRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x12\n\nproc_names\x18\x02 \x03(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"*\n\x19HostRedirectToJobResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"?\n\x15HostRemoveTagsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x18\n\x16HostRemoveTagsResponse\"R\n\x14HostRenameTagRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0f\n\x07old_tag\x18\x02 \x01(\t\x12\x0f\n\x07new_tag\x18\x03 \x01(\t\"\x17\n\x15HostRenameTagResponse\"K\n\x18HostSetAllocationRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x15\n\rallocation_id\x18\x02 \x01(\t\"\x1b\n\x19HostSetAllocationResponse\"[\n\x1bHostSetHardwareStateRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\"\n\x05state\x18\x02 \x01(\x0e\x32\x13.host.HardwareState\"\x1e\n\x1cHostSetHardwareStateResponse\"8\n\x10HostSetOsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\n\n\x02os\x18\x02 \x01(\t\"\x13\n\x11HostSetOsResponse\"T\n\x18HostSetThreadModeRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x1e\n\x04mode\x18\x02 \x01(\x0e\x32\x10.host.ThreadMode\"\x1b\n\x19HostSetThreadModeResponse\"-\n\x11HostUnlockRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostUnlockResponse\"0\n\x12OwnerDeleteRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"\x15\n\x13OwnerDeleteResponse\"2\n\x14OwnerGetDeedsRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"5\n\x15OwnerGetDeedsResponse\x12\x1c\n\x05\x64\x65\x65\x64s\x18\x01 \x01(\x0b\x32\r.host.DeedSeq\"2\n\x14OwnerGetHostsRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"5\n\x15OwnerGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"$\n\x14OwnerGetOwnerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"3\n\x15OwnerGetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"?\n\x13OwnerSetShowRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\x12\x0c\n\x04show\x18\x02 \x01(\t\"\x16\n\x14OwnerSetShowResponse\"E\n\x19OwnerTakeOwnershipRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\x12\x0c\n\x04host\x18\x02 \x01(\t\"\x1c\n\x1aOwnerTakeOwnershipResponse\"4\n\x18ProcClearRedirectRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"*\n\x19ProcClearRedirectResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"/\n\x13ProcGetFrameRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"1\n\x14ProcGetFrameResponse\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\".\n\x12ProcGetHostRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"/\n\x13ProcGetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"-\n\x11ProcGetJobRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"+\n\x12ProcGetJobResponse\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"/\n\x13ProcGetLayerRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"1\n\x14ProcGetLayerResponse\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\":\n\x13ProcGetProcsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\"4\n\x14ProcGetProcsResponse\x12\x1c\n\x05procs\x18\x01 \x01(\x0b\x32\r.host.ProcSeq\"+\n\x0fProcKillRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"\x12\n\x10ProcKillResponse\"V\n\x1aProcRedirectToGroupRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12\x0c\n\x04kill\x18\x03 \x01(\x08\",\n\x1bProcRedirectToGroupResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"R\n\x18ProcRedirectToJobRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x0c\n\x04kill\x18\x03 \x01(\x08\"*\n\x19ProcRedirectToJobResponse\x12\r\n\x05value\x18\x01 \x01(\x08\";\n\x11ProcUnbookRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x0c\n\x04kill\x18\x02 \x01(\x08\"\x14\n\x12ProcUnbookResponse\"K\n\x16ProcUnbookProcsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x0c\n\x04kill\x18\x02 \x01(\x08\",\n\x17ProcUnbookProcsResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05\"f\n\x16ProcUnbookToJobRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x19\n\x04jobs\x18\x02 \x01(\x0b\x32\x0b.job.JobSeq\x12\x0c\n\x04kill\x18\x03 \x01(\x08\",\n\x17ProcUnbookToJobResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05\"h\n\x18ProcUnbookToGroupRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x19\n\x05group\x18\x02 \x01(\x0b\x32\n.job.Group\x12\x0c\n\x04kill\x18\x03 \x01(\x08\".\n\x19ProcUnbookToGroupResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05*R\n\rHardwareState\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\r\n\tREBOOTING\x10\x02\x12\x14\n\x10REBOOT_WHEN_IDLE\x10\x03\x12\n\n\x06REPAIR\x10\x04*@\n\x0bHostTagType\x12\n\n\x06MANUAL\x10\x00\x12\x0c\n\x08HARDWARE\x10\x01\x12\t\n\x05\x41LLOC\x10\x02\x12\x0c\n\x08HOSTNAME\x10\x03*3\n\tLockState\x12\x08\n\x04OPEN\x10\x00\x12\n\n\x06LOCKED\x10\x01\x12\x10\n\x0cNIMBY_LOCKED\x10\x02*4\n\x0cRedirectType\x12\x10\n\x0cJOB_REDIRECT\x10\x00\x12\x12\n\x0eGROUP_REDIRECT\x10\x01* \n\x08RunState\x12\x08\n\x04IDLE\x10\x00\x12\n\n\x06\x42OOKED\x10\x01*-\n\nThreadMode\x12\x08\n\x04\x41UTO\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\x32\xcf\x01\n\rDeedInterface\x12;\n\x06\x44\x65lete\x12\x17.host.DeedDeleteRequest\x1a\x18.host.DeedDeleteResponse\x12>\n\x07GetHost\x12\x18.host.DeedGetHostRequest\x1a\x19.host.DeedGetHostResponse\x12\x41\n\x08GetOwner\x12\x19.host.DeedGetOwnerRequest\x1a\x1a.host.DeedGetOwnerResponse2\x8f\r\n\rHostInterface\x12G\n\nAddComment\x12\x1b.host.HostAddCommentRequest\x1a\x1c.host.HostAddCommentResponse\x12>\n\x07\x41\x64\x64Tags\x12\x18.host.HostAddTagsRequest\x1a\x19.host.HostAddTagsResponse\x12;\n\x06\x44\x65lete\x12\x17.host.HostDeleteRequest\x1a\x18.host.HostDeleteResponse\x12\x41\n\x08\x46indHost\x12\x19.host.HostFindHostRequest\x1a\x1a.host.HostFindHostResponse\x12J\n\x0bGetComments\x12\x1c.host.HostGetCommentsRequest\x1a\x1d.host.HostGetCommentsResponse\x12>\n\x07GetDeed\x12\x18.host.HostGetDeedRequest\x1a\x19.host.HostGetDeedResponse\x12>\n\x07GetHost\x12\x18.host.HostGetHostRequest\x1a\x19.host.HostGetHostResponse\x12\x41\n\x08GetHosts\x12\x19.host.HostGetHostsRequest\x1a\x1a.host.HostGetHostsResponse\x12\\\n\x11GetHostWhiteboard\x12\".host.HostGetHostWhiteboardRequest\x1a#.host.HostGetHostWhiteboardResponse\x12\x41\n\x08GetOwner\x12\x19.host.HostGetOwnerRequest\x1a\x1a.host.HostGetOwnerResponse\x12\x41\n\x08GetProcs\x12\x19.host.HostGetProcsRequest\x1a\x1a.host.HostGetProcsResponse\x12\x62\n\x13GetRenderPartitions\x12$.host.HostGetRenderPartitionsRequest\x1a%.host.HostGetRenderPartitionsResponse\x12\x35\n\x04Lock\x12\x15.host.HostLockRequest\x1a\x16.host.HostLockResponse\x12;\n\x06Reboot\x12\x17.host.HostRebootRequest\x1a\x18.host.HostRebootResponse\x12S\n\x0eRebootWhenIdle\x12\x1f.host.HostRebootWhenIdleRequest\x1a .host.HostRebootWhenIdleResponse\x12P\n\rRedirectToJob\x12\x1e.host.HostRedirectToJobRequest\x1a\x1f.host.HostRedirectToJobResponse\x12G\n\nRemoveTags\x12\x1b.host.HostRemoveTagsRequest\x1a\x1c.host.HostRemoveTagsResponse\x12\x44\n\tRenameTag\x12\x1a.host.HostRenameTagRequest\x1a\x1b.host.HostRenameTagResponse\x12P\n\rSetAllocation\x12\x1e.host.HostSetAllocationRequest\x1a\x1f.host.HostSetAllocationResponse\x12Y\n\x10SetHardwareState\x12!.host.HostSetHardwareStateRequest\x1a\".host.HostSetHardwareStateResponse\x12\x38\n\x05SetOs\x12\x16.host.HostSetOsRequest\x1a\x17.host.HostSetOsResponse\x12P\n\rSetThreadMode\x12\x1e.host.HostSetThreadModeRequest\x1a\x1f.host.HostSetThreadModeResponse\x12;\n\x06Unlock\x12\x17.host.HostUnlockRequest\x1a\x18.host.HostUnlockResponse2\xb4\x03\n\x0eOwnerInterface\x12=\n\x06\x44\x65lete\x12\x18.host.OwnerDeleteRequest\x1a\x19.host.OwnerDeleteResponse\x12\x43\n\x08GetDeeds\x12\x1a.host.OwnerGetDeedsRequest\x1a\x1b.host.OwnerGetDeedsResponse\x12\x43\n\x08GetHosts\x12\x1a.host.OwnerGetHostsRequest\x1a\x1b.host.OwnerGetHostsResponse\x12\x43\n\x08GetOwner\x12\x1a.host.OwnerGetOwnerRequest\x1a\x1b.host.OwnerGetOwnerResponse\x12@\n\x07SetShow\x12\x19.host.OwnerSetShowRequest\x1a\x1a.host.OwnerSetShowResponse\x12R\n\rTakeOwnership\x12\x1f.host.OwnerTakeOwnershipRequest\x1a .host.OwnerTakeOwnershipResponse2\xaf\x07\n\rProcInterface\x12P\n\rClearRedirect\x12\x1e.host.ProcClearRedirectRequest\x1a\x1f.host.ProcClearRedirectResponse\x12\x41\n\x08GetFrame\x12\x19.host.ProcGetFrameRequest\x1a\x1a.host.ProcGetFrameResponse\x12>\n\x07GetHost\x12\x18.host.ProcGetHostRequest\x1a\x19.host.ProcGetHostResponse\x12;\n\x06GetJob\x12\x17.host.ProcGetJobRequest\x1a\x18.host.ProcGetJobResponse\x12\x41\n\x08GetLayer\x12\x19.host.ProcGetLayerRequest\x1a\x1a.host.ProcGetLayerResponse\x12\x41\n\x08GetProcs\x12\x19.host.ProcGetProcsRequest\x1a\x1a.host.ProcGetProcsResponse\x12\x35\n\x04Kill\x12\x15.host.ProcKillRequest\x1a\x16.host.ProcKillResponse\x12V\n\x0fRedirectToGroup\x12 .host.ProcRedirectToGroupRequest\x1a!.host.ProcRedirectToGroupResponse\x12P\n\rRedirectToJob\x12\x1e.host.ProcRedirectToJobRequest\x1a\x1f.host.ProcRedirectToJobResponse\x12;\n\x06Unbook\x12\x17.host.ProcUnbookRequest\x1a\x18.host.ProcUnbookResponse\x12J\n\x0bUnbookProcs\x12\x1c.host.ProcUnbookProcsRequest\x1a\x1d.host.ProcUnbookProcsResponse\x12P\n\rUnbookToGroup\x12\x1e.host.ProcUnbookToGroupRequest\x1a\x1f.host.ProcUnbookToGroupResponse\x12J\n\x0bUnbookToJob\x12\x1c.host.ProcUnbookToJobRequest\x1a\x1d.host.ProcUnbookToJobResponseB:\n\x1e\x63om.imageworks.spcue.grpc.hostP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.hostP\001Z\026opencue_gateway/gen/go'
  _globals['_HARDWARESTATE']._serialized_start=7833
  _globals['_HARDWARESTATE']._serialized_end=7915
  _globals['_HOSTTAGTYPE']._serialized_start=7917
  _globals['_HOSTTAGTYPE']._serialized_end=7981
  _globals['_LOCKSTATE']._serialized_start=7983
  _globals['_LOCKSTATE']._serialized_end=8034
  _globals['_REDIRECTTYPE']._serialized_start=8036
  _globals['_REDIRECTTYPE']._serialized_end=8088
  _globals['_RUNSTATE']._serialized_start=8090
  _globals['_RUNSTATE']._serialized_end=8122
  _globals['_THREADMODE']._serialized_start=8124
  _globals['_THREADMODE']._serialized_end=8169
  _globals['_DEED']._serialized_start=86
  _globals['_DEED']._serialized_end=147
  _globals['_DEEDSEQ']._serialized_start=149
  _globals['_DEEDSEQ']._serialized_end=185
  _globals['_HARDWARESTATESEQ']._serialized_start=187
  _globals['_HARDWARESTATESEQ']._serialized_end=241
  _globals['_LOCKSTATESEQ']._serialized_start=243
  _globals['_LOCKSTATESEQ']._serialized_end=289
  _globals['_HOST']._serialized_start=292
  _globals['_HOST']._serialized_end=898
  _globals['_HOSTSEARCHCRITERIA']._serialized_start=901
  _globals['_HOSTSEARCHCRITERIA']._serialized_end=1077
  _globals['_HOSTSEQ']._serialized_start=1079
  _globals['_HOSTSEQ']._serialized_end=1115
  _globals['_NESTEDHOST']._serialized_start=1118
  _globals['_NESTEDHOST']._serialized_end=1766
  _globals['_NESTEDHOSTSEQ']._serialized_start=1768
  _globals['_NESTEDHOSTSEQ']._serialized_end=1823
  _globals['_NESTEDPROC']._serialized_start=1826
  _globals['_NESTEDPROC']._serialized_end=2263
  _globals['_NESTEDPROCSEQ']._serialized_start=2265
  _globals['_NESTEDPROCSEQ']._serialized_end=2320
  _globals['_OWNER']._serialized_start=2322
  _globals['_OWNER']._serialized_end=2389
  _globals['_PROC']._serialized_start=2392
  _globals['_PROC']._serialized_end=2814
  _globals['_PROCSEARCHCRITERIA']._serialized_start=2817
  _globals['_PROCSEARCHCRITERIA']._serialized_end=3233
  _globals['_PROCSEQ']._serialized_start=3235
  _globals['_PROCSEQ']._serialized_end=3271
  _globals['_DEEDDELETEREQUEST']._serialized_start=3273
  _globals['_DEEDDELETEREQUEST']._serialized_end=3318
  _globals['_DEEDDELETERESPONSE']._serialized_start=3320
  _globals['_DEEDDELETERESPONSE']._serialized_end=3340
  _globals['_DEEDGETHOSTREQUEST']._serialized_start=3342
  _globals['_DEEDGETHOSTREQUEST']._serialized_end=3388
  _globals['_DEEDGETHOSTRESPONSE']._serialized_start=3390
  _globals['_DEEDGETHOSTRESPONSE']._serialized_end=3437
  _globals['_DEEDGETOWNERREQUEST']._serialized_start=3439
  _globals['_DEEDGETOWNERREQUEST']._serialized_end=3486
  _globals['_DEEDGETOWNERRESPONSE']._serialized_start=3488
  _globals['_DEEDGETOWNERRESPONSE']._serialized_end=3538
  _globals['_HOSTADDCOMMENTREQUEST']._serialized_start=3540
  _globals['_HOSTADDCOMMENTREQUEST']._serialized_end=3628
  _globals['_HOSTADDCOMMENTRESPONSE']._serialized_start=3630
  _globals['_HOSTADDCOMMENTRESPONSE']._serialized_end=3654
  _globals['_HOSTADDTAGSREQUEST']._serialized_start=3656
  _globals['_HOSTADDTAGSREQUEST']._serialized_end=3716
  _globals['_HOSTADDTAGSRESPONSE']._serialized_start=3718
  _globals['_HOSTADDTAGSRESPONSE']._serialized_end=3739
  _globals['_HOSTDELETEREQUEST']._serialized_start=3741
  _globals['_HOSTDELETEREQUEST']._serialized_end=3786
  _globals['_HOSTDELETERESPONSE']._serialized_start=3788
  _globals['_HOSTDELETERESPONSE']._serialized_end=3808
  _globals['_HOSTFINDHOSTREQUEST']._serialized_start=3810
  _globals['_HOSTFINDHOSTREQUEST']._serialized_end=3845
  _globals['_HOSTFINDHOSTRESPONSE']._serialized_start=3847
  _globals['_HOSTFINDHOSTRESPONSE']._serialized_end=3895
  _globals['_HOSTGETCOMMENTSREQUEST']._serialized_start=3897
  _globals['_HOSTGETCOMMENTSREQUEST']._serialized_end=3947
  _globals['_HOSTGETCOMMENTSRESPONSE']._serialized_start=3949
  _globals['_HOSTGETCOMMENTSRESPONSE']._serialized_end=4013
  _globals['_HOSTGETDEEDREQUEST']._serialized_start=4015
  _globals['_HOSTGETDEEDREQUEST']._serialized_end=4061
  _globals['_HOSTGETDEEDRESPONSE']._serialized_start=4063
  _globals['_HOSTGETDEEDRESPONSE']._serialized_end=4110
  _globals['_HOSTGETHOSTREQUEST']._serialized_start=4112
  _globals['_HOSTGETHOSTREQUEST']._serialized_end=4144
  _globals['_HOSTGETHOSTRESPONSE']._serialized_start=4146
  _globals['_HOSTGETHOSTRESPONSE']._serialized_end=4193
  _globals['_HOSTGETHOSTSREQUEST']._serialized_start=4195
  _globals['_HOSTGETHOSTSREQUEST']._serialized_end=4253
  _globals['_HOSTGETHOSTSRESPONSE']._serialized_start=4255
  _globals['_HOSTGETHOSTSRESPONSE']._serialized_end=4307
  _globals['_HOSTGETHOSTWHITEBOARDREQUEST']._serialized_start=4309
  _globals['_HOSTGETHOSTWHITEBOARDREQUEST']._serialized_end=4339
  _globals['_HOSTGETHOSTWHITEBOARDRESPONSE']._serialized_start=4341
  _globals['_HOSTGETHOSTWHITEBOARDRESPONSE']._serialized_end=4415
  _globals['_HOSTGETOWNERREQUEST']._serialized_start=4417
  _globals['_HOSTGETOWNERREQUEST']._serialized_end=4464
  _globals['_HOSTGETOWNERRESPONSE']._serialized_start=4466
  _globals['_HOSTGETOWNERRESPONSE']._serialized_end=4516
  _globals['_HOSTGETPROCSREQUEST']._serialized_start=4518
  _globals['_HOSTGETPROCSREQUEST']._serialized_end=4565
  _globals['_HOSTGETPROCSRESPONSE']._serialized_start=4567
  _globals['_HOSTGETPROCSRESPONSE']._serialized_end=4619
  _globals['_HOSTGETRENDERPARTITIONSREQUEST']._serialized_start=4621
  _globals['_HOSTGETRENDERPARTITIONSREQUEST']._serialized_end=4679
  _globals['_HOSTGETRENDERPARTITIONSRESPONSE']._serialized_start=4681
  _globals['_HOSTGETRENDERPARTITIONSRESPONSE']._serialized_end=4778
  _globals['_HOSTLOCKREQUEST']._serialized_start=4780
  _globals['_HOSTLOCKREQUEST']._serialized_end=4823
  _globals['_HOSTLOCKRESPONSE']._serialized_start=4825
  _globals['_HOSTLOCKRESPONSE']._serialized_end=4843
  _globals['_HOSTREBOOTREQUEST']._serialized_start=4845
  _globals['_HOSTREBOOTREQUEST']._serialized_end=4890
  _globals['_HOSTREBOOTRESPONSE']._serialized_start=4892
  _globals['_HOSTREBOOTRESPONSE']._serialized_end=4912
  _globals['_HOSTREBOOTWHENIDLEREQUEST']._serialized_start=4914
  _globals['_HOSTREBOOTWHENIDLEREQUEST']._serialized_end=4967
  _globals['_HOSTREBOOTWHENIDLERESPONSE']._serialized_start=4969
  _globals['_HOSTREBOOTWHENIDLERESPONSE']._serialized_end=4997
  _globals['_HOSTREDIRECTTOJOBREQUEST']._serialized_start=4999
  _globals['_HOSTREDIRECTTOJOBREQUEST']._serialized_end=5087
  _globals['_HOSTREDIRECTTOJOBRESPONSE']._serialized_start=5089
  _globals['_HOSTREDIRECTTOJOBRESPONSE']._serialized_end=5131
  _globals['_HOSTREMOVETAGSREQUEST']._serialized_start=5133
  _globals['_HOSTREMOVETAGSREQUEST']._serialized_end=5196
  _globals['_HOSTREMOVETAGSRESPONSE']._serialized_start=5198
  _globals['_HOSTREMOVETAGSRESPONSE']._serialized_end=5222
  _globals['_HOSTRENAMETAGREQUEST']._serialized_start=5224
  _globals['_HOSTRENAMETAGREQUEST']._serialized_end=5306
  _globals['_HOSTRENAMETAGRESPONSE']._serialized_start=5308
  _globals['_HOSTRENAMETAGRESPONSE']._serialized_end=5331
  _globals['_HOSTSETALLOCATIONREQUEST']._serialized_start=5333
  _globals['_HOSTSETALLOCATIONREQUEST']._serialized_end=5408
  _globals['_HOSTSETALLOCATIONRESPONSE']._serialized_start=5410
  _globals['_HOSTSETALLOCATIONRESPONSE']._serialized_end=5437
  _globals['_HOSTSETHARDWARESTATEREQUEST']._serialized_start=5439
  _globals['_HOSTSETHARDWARESTATEREQUEST']._serialized_end=5530
  _globals['_HOSTSETHARDWARESTATERESPONSE']._serialized_start=5532
  _globals['_HOSTSETHARDWARESTATERESPONSE']._serialized_end=5562
  _globals['_HOSTSETOSREQUEST']._serialized_start=5564
  _globals['_HOSTSETOSREQUEST']._serialized_end=5620
  _globals['_HOSTSETOSRESPONSE']._serialized_start=5622
  _globals['_HOSTSETOSRESPONSE']._serialized_end=5641
  _globals['_HOSTSETTHREADMODEREQUEST']._serialized_start=5643
  _globals['_HOSTSETTHREADMODEREQUEST']._serialized_end=5727
  _globals['_HOSTSETTHREADMODERESPONSE']._serialized_start=5729
  _globals['_HOSTSETTHREADMODERESPONSE']._serialized_end=5756
  _globals['_HOSTUNLOCKREQUEST']._serialized_start=5758
  _globals['_HOSTUNLOCKREQUEST']._serialized_end=5803
  _globals['_HOSTUNLOCKRESPONSE']._serialized_start=5805
  _globals['_HOSTUNLOCKRESPONSE']._serialized_end=5825
  _globals['_OWNERDELETEREQUEST']._serialized_start=5827
  _globals['_OWNERDELETEREQUEST']._serialized_end=5875
  _globals['_OWNERDELETERESPONSE']._serialized_start=5877
  _globals['_OWNERDELETERESPONSE']._serialized_end=5898
  _globals['_OWNERGETDEEDSREQUEST']._serialized_start=5900
  _globals['_OWNERGETDEEDSREQUEST']._serialized_end=5950
  _globals['_OWNERGETDEEDSRESPONSE']._serialized_start=5952
  _globals['_OWNERGETDEEDSRESPONSE']._serialized_end=6005
  _globals['_OWNERGETHOSTSREQUEST']._serialized_start=6007
  _globals['_OWNERGETHOSTSREQUEST']._serialized_end=6057
  _globals['_OWNERGETHOSTSRESPONSE']._serialized_start=6059
  _globals['_OWNERGETHOSTSRESPONSE']._serialized_end=6112
  _globals['_OWNERGETOWNERREQUEST']._serialized_start=6114
  _globals['_OWNERGETOWNERREQUEST']._serialized_end=6150
  _globals['_OWNERGETOWNERRESPONSE']._serialized_start=6152
  _globals['_OWNERGETOWNERRESPONSE']._serialized_end=6203
  _globals['_OWNERSETSHOWREQUEST']._serialized_start=6205
  _globals['_OWNERSETSHOWREQUEST']._serialized_end=6268
  _globals['_OWNERSETSHOWRESPONSE']._serialized_start=6270
  _globals['_OWNERSETSHOWRESPONSE']._serialized_end=6292
  _globals['_OWNERTAKEOWNERSHIPREQUEST']._serialized_start=6294
  _globals['_OWNERTAKEOWNERSHIPREQUEST']._serialized_end=6363
  _globals['_OWNERTAKEOWNERSHIPRESPONSE']._serialized_start=6365
  _globals['_OWNERTAKEOWNERSHIPRESPONSE']._serialized_end=6393
  _globals['_PROCCLEARREDIRECTREQUEST']._serialized_start=6395
  _globals['_PROCCLEARREDIRECTREQUEST']._serialized_end=6447
  _globals['_PROCCLEARREDIRECTRESPONSE']._serialized_start=6449
  _globals['_PROCCLEARREDIRECTRESPONSE']._serialized_end=6491
  _globals['_PROCGETFRAMEREQUEST']._serialized_start=6493
  _globals['_PROCGETFRAMEREQUEST']._serialized_end=6540
  _globals['_PROCGETFRAMERESPONSE']._serialized_start=6542
  _globals['_PROCGETFRAMERESPONSE']._serialized_end=6591
  _globals['_PROCGETHOSTREQUEST']._serialized_start=6593
  _globals['_PROCGETHOSTREQUEST']._serialized_end=6639
  _globals['_PROCGETHOSTRESPONSE']._serialized_start=6641
  _globals['_PROCGETHOSTRESPONSE']._serialized_end=6688
  _globals['_PROCGETJOBREQUEST']._serialized_start=6690
  _globals['_PROCGETJOBREQUEST']._serialized_end=6735
  _globals['_PROCGETJOBRESPONSE']._serialized_start=6737
  _globals['_PROCGETJOBRESPONSE']._serialized_end=6780
  _globals['_PROCGETLAYERREQUEST']._serialized_start=6782
  _globals['_PROCGETLAYERREQUEST']._serialized_end=6829
  _globals['_PROCGETLAYERRESPONSE']._serialized_start=6831
  _globals['_PROCGETLAYERRESPONSE']._serialized_end=6880
  _globals['_PROCGETPROCSREQUEST']._serialized_start=6882
  _globals['_PROCGETPROCSREQUEST']._serialized_end=6940
  _globals['_PROCGETPROCSRESPONSE']._serialized_start=6942
  _globals['_PROCGETPROCSRESPONSE']._serialized_end=6994
  _globals['_PROCKILLREQUEST']._serialized_start=6996
  _globals['_PROCKILLREQUEST']._serialized_end=7039
  _globals['_PROCKILLRESPONSE']._serialized_start=7041
  _globals['_PROCKILLRESPONSE']._serialized_end=7059
  _globals['_PROCREDIRECTTOGROUPREQUEST']._serialized_start=7061
  _globals['_PROCREDIRECTTOGROUPREQUEST']._serialized_end=7147
  _globals['_PROCREDIRECTTOGROUPRESPONSE']._serialized_start=7149
  _globals['_PROCREDIRECTTOGROUPRESPONSE']._serialized_end=7193
  _globals['_PROCREDIRECTTOJOBREQUEST']._serialized_start=7195
  _globals['_PROCREDIRECTTOJOBREQUEST']._serialized_end=7277
  _globals['_PROCREDIRECTTOJOBRESPONSE']._serialized_start=7279
  _globals['_PROCREDIRECTTOJOBRESPONSE']._serialized_end=7321
  _globals['_PROCUNBOOKREQUEST']._serialized_start=7323
  _globals['_PROCUNBOOKREQUEST']._serialized_end=7382
  _globals['_PROCUNBOOKRESPONSE']._serialized_start=7384
  _globals['_PROCUNBOOKRESPONSE']._serialized_end=7404
  _globals['_PROCUNBOOKPROCSREQUEST']._serialized_start=7406
  _globals['_PROCUNBOOKPROCSREQUEST']._serialized_end=7481
  _globals['_PROCUNBOOKPROCSRESPONSE']._serialized_start=7483
  _globals['_PROCUNBOOKPROCSRESPONSE']._serialized_end=7527
  _globals['_PROCUNBOOKTOJOBREQUEST']._serialized_start=7529
  _globals['_PROCUNBOOKTOJOBREQUEST']._serialized_end=7631
  _globals['_PROCUNBOOKTOJOBRESPONSE']._serialized_start=7633
  _globals['_PROCUNBOOKTOJOBRESPONSE']._serialized_end=7677
  _globals['_PROCUNBOOKTOGROUPREQUEST']._serialized_start=7679
  _globals['_PROCUNBOOKTOGROUPREQUEST']._serialized_end=7783
  _globals['_PROCUNBOOKTOGROUPRESPONSE']._serialized_start=7785
  _globals['_PROCUNBOOKTOGROUPRESPONSE']._serialized_end=7831
  _globals['_DEEDINTERFACE']._serialized_start=8172
  _globals['_DEEDINTERFACE']._serialized_end=8379
  _globals['_HOSTINTERFACE']._serialized_start=8382
  _globals['_HOSTINTERFACE']._serialized_end=10061
  _globals['_OWNERINTERFACE']._serialized_start=10064
  _globals['_OWNERINTERFACE']._serialized_end=10500
  _globals['_PROCINTERFACE']._serialized_start=10503
  _globals['_PROCINTERFACE']._serialized_end=11446
# @@protoc_insertion_point(module_scope)



"""
Custom build script for building the package
"""
import glob
import os
import re
import subprocess
import sys

from hatchling.builders.hooks.plugin.interface import BuildHookInterface
from hatchling.plugin import hookimpl

class CustomBuildHook(BuildHookInterface):
    """
    Custom Hatch build hook for compiling Protocol Buffer definitions (.proto).

    This hook integrates with the Hatch build process and is triggered
    during the initialization phase via its `initialize` method before the
    main build process begins.

    It performs the following main tasks:
    1. Locates all `.proto` files within the project's `proto/` subdirectory.
    2. Invokes the `grpc_tools.protoc` compiler to generate the corresponding
       Python modules (`_pb2.py`) and gRPC service modules (`_pb2_grpc.py`).
    3. Places the generated Python files into the `opencue_proto/`
       subdirectory, making them available for inclusion in the final package.
    4. Post-processes the generated Python files to modify imports between
       compiled proto modules, changing them from absolute (e.g., `import X_pb2`)
       to relative (e.g., `from . import X_pb2`). This ensures the generated
       code works correctly when installed as part of the `opencue_proto` package.

    This automation avoids the need to manually compile protos and commit the
    generated code to the repository.
    """
    def initialize(self, version, build_data):
        # Compile protocol buffers
        proto_dir = os.path.join(self.root, "src")
        output_dir = os.path.join(self.root, "opencue_proto")
        if not os.path.exists(output_dir):
            os.makedirs(output_dir)
        proto_files = [f for f in os.listdir(proto_dir) if f.endswith(".proto")]

        if not proto_files:
            print("No .proto files found.")
            return

        command = [
            sys.executable,
            "-m",
            "grpc_tools.protoc",
            f"-I={proto_dir}",
            f"--python_out={output_dir}",
            f"--grpc_python_out={output_dir}",
        ] + [os.path.join(proto_dir, f) for f in proto_files]

        print(f"Compiling protocol buffers: {' '.join(command)}")
        subprocess.check_call(command)

        # Fix compiled proto imports
        pattern = re.compile(r"^import \w+ as \w+_pb2")
        for filepath in glob.glob(os.path.join(output_dir, "*_pb2*.py")):
            filedata = []
            with open(filepath) as f:
                for line in f.readlines():
                    match = pattern.match(line)
                    if match is not None:
                        line = f"from . {line}"
                    filedata.append(line.strip("\n"))
            with open(filepath, "w") as f:
                f.write("\n".join(filedata))

@hookimpl
def hatch_register_build_hook():
    return CustomBuildHook()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import facility_pb2 as facility__pb2


class FacilityInterfaceStub(object):
    """-------- Services --------

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/facility.FacilityInterface/Create',
                request_serializer=facility__pb2.FacilityCreateRequest.SerializeToString,
                response_deserializer=facility__pb2.FacilityCreateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/facility.FacilityInterface/Delete',
                request_serializer=facility__pb2.FacilityDeleteRequest.SerializeToString,
                response_deserializer=facility__pb2.FacilityDeleteResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/facility.FacilityInterface/Get',
                request_serializer=facility__pb2.FacilityGetRequest.SerializeToString,
                response_deserializer=facility__pb2.FacilityGetResponse.FromString,
                )
        self.Rename = channel.unary_unary(
                '/facility.FacilityInterface/Rename',
                request_serializer=facility__pb2.FacilityRenameRequest.SerializeToString,
                response_deserializer=facility__pb2.FacilityRenameResponse.FromString,
                )
        self.GetAllocations = channel.unary_unary(
                '/facility.FacilityInterface/GetAllocations',
                request_serializer=facility__pb2.FacilityGetAllocationsRequest.SerializeToString,
                response_deserializer=facility__pb2.FacilityGetAllocationsResponse.FromString,
                )


class FacilityInterfaceServicer(object):
    """-------- Services --------

    """

    def Create(self, request, context):
        """Create a facility.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """A facility is never really deleted, just make inactive.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Look up a facility by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rename(self, request, context):
        """Rename the facility to a given name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllocations(self, request, context):
        """Get Allocations associated with this facility.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FacilityInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=facility__pb2.FacilityCreateRequest.FromString,
                    response_serializer=facility__pb2.FacilityCreateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=facility__pb2.FacilityDeleteRequest.FromString,
                    response_serializer=facility__pb2.FacilityDeleteResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=facility__pb2.FacilityGetRequest.FromString,
                    response_serializer=facility__pb2.FacilityGetResponse.SerializeToString,
            ),
            'Rename': grpc.unary_unary_rpc_method_handler(
                    servicer.Rename,
                    request_deserializer=facility__pb2.FacilityRenameRequest.FromString,
                    response_serializer=facility__pb2.FacilityRenameResponse.SerializeToString,
            ),
            'GetAllocations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllocations,
                    request_deserializer=facility__pb2.FacilityGetAllocationsRequest.FromString,
                    response_serializer=facility__pb2.FacilityGetAllocationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'facility.FacilityInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FacilityInterface(object):
    """-------- Services --------

    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.FacilityInterface/Create',
            facility__pb2.FacilityCreateRequest.SerializeToString,
            facility__pb2.FacilityCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.FacilityInterface/Delete',
            facility__pb2.FacilityDeleteRequest.SerializeToString,
            facility__pb2.FacilityDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.FacilityInterface/Get',
            facility__pb2.FacilityGetRequest.SerializeToString,
            facility__pb2.FacilityGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rename(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.FacilityInterface/Rename',
            facility__pb2.FacilityRenameRequest.SerializeToString,
            facility__pb2.FacilityRenameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllocations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.FacilityInterface/GetAllocations',
            facility__pb2.FacilityGetAllocationsRequest.SerializeToString,
            facility__pb2.FacilityGetAllocationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class AllocationInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/facility.AllocationInterface/Create',
                request_serializer=facility__pb2.AllocCreateRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocCreateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/facility.AllocationInterface/Delete',
                request_serializer=facility__pb2.AllocDeleteRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocDeleteResponse.FromString,
                )
        self.Find = channel.unary_unary(
                '/facility.AllocationInterface/Find',
                request_serializer=facility__pb2.AllocFindRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocFindResponse.FromString,
                )
        self.FindHosts = channel.unary_unary(
                '/facility.AllocationInterface/FindHosts',
                request_serializer=facility__pb2.AllocFindHostsRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocFindHostsResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/facility.AllocationInterface/Get',
                request_serializer=facility__pb2.AllocGetRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocGetResponse.FromString,
                )
        self.GetAll = channel.unary_unary(
                '/facility.AllocationInterface/GetAll',
                request_serializer=facility__pb2.AllocGetAllRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocGetAllResponse.FromString,
                )
        self.GetHosts = channel.unary_unary(
                '/facility.AllocationInterface/GetHosts',
                request_serializer=facility__pb2.AllocGetHostsRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocGetHostsResponse.FromString,
                )
        self.GetSubscriptions = channel.unary_unary(
                '/facility.AllocationInterface/GetSubscriptions',
                request_serializer=facility__pb2.AllocGetSubscriptionsRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocGetSubscriptionsResponse.FromString,
                )
        self.ReparentHosts = channel.unary_unary(
                '/facility.AllocationInterface/ReparentHosts',
                request_serializer=facility__pb2.AllocReparentHostsRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocReparentHostsResponse.FromString,
                )
        self.SetBillable = channel.unary_unary(
                '/facility.AllocationInterface/SetBillable',
                request_serializer=facility__pb2.AllocSetBillableRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocSetBillableResponse.FromString,
                )
        self.SetName = channel.unary_unary(
                '/facility.AllocationInterface/SetName',
                request_serializer=facility__pb2.AllocSetNameRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocSetNameResponse.FromString,
                )
        self.SetTag = channel.unary_unary(
                '/facility.AllocationInterface/SetTag',
                request_serializer=facility__pb2.AllocSetTagRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocSetTagResponse.FromString,
                )
        self.GetDefault = channel.unary_unary(
                '/facility.AllocationInterface/GetDefault',
                request_serializer=facility__pb2.AllocGetDefaultRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocGetDefaultResponse.FromString,
                )
        self.SetDefault = channel.unary_unary(
                '/facility.AllocationInterface/SetDefault',
                request_serializer=facility__pb2.AllocSetDefaultRequest.SerializeToString,
                response_deserializer=facility__pb2.AllocSetDefaultResponse.FromString,
                )


class AllocationInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete this allocation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Find an allocation by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindHosts(self, request, context):
        """Use HostSearchCriteria to find a list of hosts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Look up an allocation by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAll(self, request, context):
        """Return a list of all allocations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHosts(self, request, context):
        """Returns the list of hosts in this allocation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubscriptions(self, request, context):
        """Returns all subscriptions for this allocation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReparentHosts(self, request, context):
        """Assigns a list of hosts to this allocation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBillable(self, request, context):
        """Set an allocation billable or not billable.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetName(self, request, context):
        """Set the allocation name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTag(self, request, context):
        """Set the allocation tag.  Setting this will re-tag all the hosts in this allocation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefault(self, request, context):
        """Return the default allocation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefault(self, request, context):
        """Set the default allocation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AllocationInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=facility__pb2.AllocCreateRequest.FromString,
                    response_serializer=facility__pb2.AllocCreateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=facility__pb2.AllocDeleteRequest.FromString,
                    response_serializer=facility__pb2.AllocDeleteResponse.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=facility__pb2.AllocFindRequest.FromString,
                    response_serializer=facility__pb2.AllocFindResponse.SerializeToString,
            ),
            'FindHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.FindHosts,
                    request_deserializer=facility__pb2.AllocFindHostsRequest.FromString,
                    response_serializer=facility__pb2.AllocFindHostsResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=facility__pb2.AllocGetRequest.FromString,
                    response_serializer=facility__pb2.AllocGetResponse.SerializeToString,
            ),
            'GetAll': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAll,
                    request_deserializer=facility__pb2.AllocGetAllRequest.FromString,
                    response_serializer=facility__pb2.AllocGetAllResponse.SerializeToString,
            ),
            'GetHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHosts,
                    request_deserializer=facility__pb2.AllocGetHostsRequest.FromString,
                    response_serializer=facility__pb2.AllocGetHostsResponse.SerializeToString,
            ),
            'GetSubscriptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubscriptions,
                    request_deserializer=facility__pb2.AllocGetSubscriptionsRequest.FromString,
                    response_serializer=facility__pb2.AllocGetSubscriptionsResponse.SerializeToString,
            ),
            'ReparentHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.ReparentHosts,
                    request_deserializer=facility__pb2.AllocReparentHostsRequest.FromString,
                    response_serializer=facility__pb2.AllocReparentHostsResponse.SerializeToString,
            ),
            'SetBillable': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBillable,
                    request_deserializer=facility__pb2.AllocSetBillableRequest.FromString,
                    response_serializer=facility__pb2.AllocSetBillableResponse.SerializeToString,
            ),
            'SetName': grpc.unary_unary_rpc_method_handler(
                    servicer.SetName,
                    request_deserializer=facility__pb2.AllocSetNameRequest.FromString,
                    response_serializer=facility__pb2.AllocSetNameResponse.SerializeToString,
            ),
            'SetTag': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTag,
                    request_deserializer=facility__pb2.AllocSetTagRequest.FromString,
                    response_serializer=facility__pb2.AllocSetTagResponse.SerializeToString,
            ),
            'GetDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefault,
                    request_deserializer=facility__pb2.AllocGetDefaultRequest.FromString,
                    response_serializer=facility__pb2.AllocGetDefaultResponse.SerializeToString,
            ),
            'SetDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefault,
                    request_deserializer=facility__pb2.AllocSetDefaultRequest.FromString,
                    response_serializer=facility__pb2.AllocSetDefaultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'facility.AllocationInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AllocationInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/Create',
            facility__pb2.AllocCreateRequest.SerializeToString,
            facility__pb2.AllocCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/Delete',
            facility__pb2.AllocDeleteRequest.SerializeToString,
            facility__pb2.AllocDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/Find',
            facility__pb2.AllocFindRequest.SerializeToString,
            facility__pb2.AllocFindResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/FindHosts',
            facility__pb2.AllocFindHostsRequest.SerializeToString,
            facility__pb2.AllocFindHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/Get',
            facility__pb2.AllocGetRequest.SerializeToString,
            facility__pb2.AllocGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/GetAll',
            facility__pb2.AllocGetAllRequest.SerializeToString,
            facility__pb2.AllocGetAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/GetHosts',
            facility__pb2.AllocGetHostsRequest.SerializeToString,
            facility__pb2.AllocGetHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSubscriptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/GetSubscriptions',
            facility__pb2.AllocGetSubscriptionsRequest.SerializeToString,
            facility__pb2.AllocGetSubscriptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReparentHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/ReparentHosts',
            facility__pb2.AllocReparentHostsRequest.SerializeToString,
            facility__pb2.AllocReparentHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBillable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/SetBillable',
            facility__pb2.AllocSetBillableRequest.SerializeToString,
            facility__pb2.AllocSetBillableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/SetName',
            facility__pb2.AllocSetNameRequest.SerializeToString,
            facility__pb2.AllocSetNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/SetTag',
            facility__pb2.AllocSetTagRequest.SerializeToString,
            facility__pb2.AllocSetTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/GetDefault',
            facility__pb2.AllocGetDefaultRequest.SerializeToString,
            facility__pb2.AllocGetDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/facility.AllocationInterface/SetDefault',
            facility__pb2.AllocSetDefaultRequest.SerializeToString,
            facility__pb2.AllocSetDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import limit_pb2 as limit__pb2


class LimitInterfaceStub(object):
    """The Limit class contains data that allows users to place limits
    on the maximum number of running frames for a certain type of layer.

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/limit.LimitInterface/Create',
                request_serializer=limit__pb2.LimitCreateRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitCreateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/limit.LimitInterface/Delete',
                request_serializer=limit__pb2.LimitDeleteRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitDeleteResponse.FromString,
                )
        self.Find = channel.unary_unary(
                '/limit.LimitInterface/Find',
                request_serializer=limit__pb2.LimitFindRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitFindResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/limit.LimitInterface/Get',
                request_serializer=limit__pb2.LimitGetRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitGetResponse.FromString,
                )
        self.GetAll = channel.unary_unary(
                '/limit.LimitInterface/GetAll',
                request_serializer=limit__pb2.LimitGetAllRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitGetAllResponse.FromString,
                )
        self.Rename = channel.unary_unary(
                '/limit.LimitInterface/Rename',
                request_serializer=limit__pb2.LimitRenameRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitRenameResponse.FromString,
                )
        self.SetMaxValue = channel.unary_unary(
                '/limit.LimitInterface/SetMaxValue',
                request_serializer=limit__pb2.LimitSetMaxValueRequest.SerializeToString,
                response_deserializer=limit__pb2.LimitSetMaxValueResponse.FromString,
                )


class LimitInterfaceServicer(object):
    """The Limit class contains data that allows users to place limits
    on the maximum number of running frames for a certain type of layer.

    -------- Services --------]

    """

    def Create(self, request, context):
        """Create a new limit with a name and max value
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete the specified limit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Find a limit by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get a limit by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAll(self, request, context):
        """Get all limits
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rename(self, request, context):
        """Rename an existing limit
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMaxValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LimitInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=limit__pb2.LimitCreateRequest.FromString,
                    response_serializer=limit__pb2.LimitCreateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=limit__pb2.LimitDeleteRequest.FromString,
                    response_serializer=limit__pb2.LimitDeleteResponse.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=limit__pb2.LimitFindRequest.FromString,
                    response_serializer=limit__pb2.LimitFindResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=limit__pb2.LimitGetRequest.FromString,
                    response_serializer=limit__pb2.LimitGetResponse.SerializeToString,
            ),
            'GetAll': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAll,
                    request_deserializer=limit__pb2.LimitGetAllRequest.FromString,
                    response_serializer=limit__pb2.LimitGetAllResponse.SerializeToString,
            ),
            'Rename': grpc.unary_unary_rpc_method_handler(
                    servicer.Rename,
                    request_deserializer=limit__pb2.LimitRenameRequest.FromString,
                    response_serializer=limit__pb2.LimitRenameResponse.SerializeToString,
            ),
            'SetMaxValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMaxValue,
                    request_deserializer=limit__pb2.LimitSetMaxValueRequest.FromString,
                    response_serializer=limit__pb2.LimitSetMaxValueResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'limit.LimitInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LimitInterface(object):
    """The Limit class contains data that allows users to place limits
    on the maximum number of running frames for a certain type of layer.

    -------- Services --------]

    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/Create',
            limit__pb2.LimitCreateRequest.SerializeToString,
            limit__pb2.LimitCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/Delete',
            limit__pb2.LimitDeleteRequest.SerializeToString,
            limit__pb2.LimitDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/Find',
            limit__pb2.LimitFindRequest.SerializeToString,
            limit__pb2.LimitFindResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/Get',
            limit__pb2.LimitGetRequest.SerializeToString,
            limit__pb2.LimitGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/GetAll',
            limit__pb2.LimitGetAllRequest.SerializeToString,
            limit__pb2.LimitGetAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rename(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/Rename',
            limit__pb2.LimitRenameRequest.SerializeToString,
            limit__pb2.LimitRenameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMaxValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/limit.LimitInterface/SetMaxValue',
            limit__pb2.LimitSetMaxValueRequest.SerializeToString,
            limit__pb2.LimitSetMaxValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: subscription.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12subscription.proto\x12\x0csubscription\"\xb2\x01\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x17\n\x0f\x61llocation_name\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x05\x12\r\n\x05\x62urst\x18\x07 \x01(\x05\x12\x16\n\x0ereserved_cores\x18\x08 \x01(\x05\x12\x15\n\rreserved_gpus\x18\t \x01(\x05\"D\n\x0fSubscriptionSeq\x12\x31\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x1a.subscription.Subscription\"M\n\x19SubscriptionDeleteRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"\x1c\n\x1aSubscriptionDeleteResponse\"\'\n\x17SubscriptionFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"L\n\x18SubscriptionFindResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"$\n\x16SubscriptionGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x17SubscriptionGetResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"^\n\x1bSubscriptionSetBurstRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\x12\r\n\x05\x62urst\x18\x02 \x01(\x05\"\x1e\n\x1cSubscriptionSetBurstResponse\"`\n\x1aSubscriptionSetSizeRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\x12\x10\n\x08new_size\x18\x02 \x01(\x05\"\x1d\n\x1bSubscriptionSetSizeResponse2\xe2\x03\n\x15SubscriptionInterface\x12[\n\x06\x44\x65lete\x12\'.subscription.SubscriptionDeleteRequest\x1a(.subscription.SubscriptionDeleteResponse\x12U\n\x04\x46ind\x12%.subscription.SubscriptionFindRequest\x1a&.subscription.SubscriptionFindResponse\x12R\n\x03Get\x12$.subscription.SubscriptionGetRequest\x1a%.subscription.SubscriptionGetResponse\x12\x61\n\x08SetBurst\x12).subscription.SubscriptionSetBurstRequest\x1a*.subscription.SubscriptionSetBurstResponse\x12^\n\x07SetSize\x12(.subscription.SubscriptionSetSizeRequest\x1a).subscription.SubscriptionSetSizeResponseBB\n&com.imageworks.spcue.grpc.subscriptionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'subscription_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.imageworks.spcue.grpc.subscriptionP\001Z\026opencue_gateway/gen/go'
  _globals['_SUBSCRIPTION']._serialized_start=37
  _globals['_SUBSCRIPTION']._serialized_end=215
  _globals['_SUBSCRIPTIONSEQ']._serialized_start=217
  _globals['_SUBSCRIPTIONSEQ']._serialized_end=285
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=287
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=364
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=366
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=394
  _globals['_SUBSCRIPTIONFINDREQUEST']._serialized_start=396
  _globals['_SUBSCRIPTIONFINDREQUEST']._serialized_end=435
  _globals['_SUBSCRIPTIONFINDRESPONSE']._serialized_start=437
  _globals['_SUBSCRIPTIONFINDRESPONSE']._serialized_end=513
  _globals['_SUBSCRIPTIONGETREQUEST']._serialized_start=515
  _globals['_SUBSCRIPTIONGETREQUEST']._serialized_end=551
  _globals['_SUBSCRIPTIONGETRESPONSE']._serialized_start=553
  _globals['_SUBSCRIPTIONGETRESPONSE']._serialized_end=628
  _globals['_SUBSCRIPTIONSETBURSTREQUEST']._serialized_start=630
  _globals['_SUBSCRIPTIONSETBURSTREQUEST']._serialized_end=724
  _globals['_SUBSCRIPTIONSETBURSTRESPONSE']._serialized_start=726
  _globals['_SUBSCRIPTIONSETBURSTRESPONSE']._serialized_end=756
  _globals['_SUBSCRIPTIONSETSIZEREQUEST']._serialized_start=758
  _globals['_SUBSCRIPTIONSETSIZEREQUEST']._serialized_end=854
  _globals['_SUBSCRIPTIONSETSIZERESPONSE']._serialized_start=856
  _globals['_SUBSCRIPTIONSETSIZERESPONSE']._serialized_end=885
  _globals['_SUBSCRIPTIONINTERFACE']._serialized_start=888
  _globals['_SUBSCRIPTIONINTERFACE']._serialized_end=1370
# @@protoc_insertion_point(module_scope)